# dollar-yen
Convert dollars to yen.
This project (GitHub and PYPI) was created for the first time. 

Please give me any comments and opinions.
# how to install dollar-yen
    pip install dollar-yen

# how to run dollar-yen
Pass through the path before executing.


    $ dollar_yen
or

    import dollar_yen as dy
    dy.now() # The current rate is displayed
    yen = dy.exchange(num) # Let's calculate how much the one in parentheses () is worth in Japanese yen now.
![590ce8ba-7ad5-4bf5-8808-945fc720d9b7](https://github.com/spc-nmurata/dollar-yen/assets/172005627/fcde4682-5f00-470c-bb6a-1956b6588a36)
